<?php

namespace Drupal\page_deletion_guard\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\node\NodeAccessControlHandler;

/**
 * Defines the access control handler to check/prevent deletion of locked pages.
 */
class PageDeletionGuardNodeAccessControlHandler extends NodeAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  public function access(EntityInterface $entity, $operation, ?AccountInterface $account = NULL, $return_as_object = FALSE) {
    $node_id = $entity->id();
    $config = \Drupal::config('page_deletion_guard.settings');
    $locked_pages = $config->get('locked_pages.nodes') ?: [];

    if ($operation === 'delete' && in_array($node_id, $locked_pages)) {
      $result = AccessResult::forbidden("Protected Node")->cachePerPermissions();
      return $return_as_object ? $result : $result->isAllowed();
    }

    return parent::access($entity, $operation, $account, TRUE);
  }

}
